use std::{
	env::{current_dir, var},
	path::Path
};

use toml::{
	Value,
	map::Map
};

use crate::{ error, util };

pub struct Config {
	pub local: Option<Map<String, Value>>,
	pub global: Option<Map<String, Value>>,
	pub local_path: Option<String>,
	pub global_path: Option<String>
}

impl Config {
	pub fn new() -> Config {
		//	initialize global config, if it exists
		let str_path_global = var("HOME").unwrap() + "/.config/open.toml";
		let path_global = Path::new(&str_path_global);
		let global = util::read_toml(path_global);

		//	propagate up for local config, if it exists
		let cwd = current_dir().unwrap();
		let mut path_local = Path::new(&cwd);
		let mut local = None;
		while let Some(parent) = path_local.parent() {
			let file_local = path_local.join(".open");
			if let Some(toml) = util::read_toml(file_local.as_path()) {
				local = Some(toml);
				break;
			}

			path_local = parent;
		}

		if global.is_none() && local.is_none() { error::no_configs(); }

		// prepare path vars
		let global_path: Option<String> =
			if global.is_some() { Some(path_global.to_string_lossy().into()) }
			else { None };
		let local_path =
			if local.is_some() { Some(path_local.join(".open").to_string_lossy().into()) }
			else { None };

		Config {
			global,
			local,
			local_path,
			global_path
		}
	}
	pub fn get(&self, key: &str) -> Option<Value> {
		if let Some(local) = &self.local {
			if let Some(result) = local.get(key) { return Some(result.to_owned()); }
		}

		if let Some(global) = &self.global {
			if let Some(result) = global.get(key) { return Some(result.to_owned()); }
		}

		None
	}
}
