use std::{
	fs::read_to_string,
	path::Path
};

use toml::{
	self,
	Value,

	map::Map,
	value::Array,
};

///	gets array entries with matching "match" values.
pub fn matches(macrosection: Array, to_match: String) -> Vec<Value> {
	macrosection.iter().filter(|value| {
		if let Some(table) = value.as_table() {
			match table.get("match").unwrap() {
				Value::String(target)	=> *target == to_match,
				Value::Array(values)	=> values.contains(&Value::String(to_match.clone())),
				_ => false
			}
		} else { false }
	}).map(|value| value.to_owned()).collect()
}

pub fn read_toml(path: &Path) -> Option<Map<String, Value>> {
	if path.exists() {
		if let Ok(raw) = read_to_string(path) {
			if let Ok(Value::Table(toml)) = toml::from_str(&raw) {
				return Some(toml);
			}
		}
	}
	None
}

